@@ -107,6 +107,7 @@ class Secret(object):
         tried = {}
         for n, m in [
                     ("env", lambda:os.environ.get("DDA_TOKEN").strip()),
+                    ("env-usertoken", lambda:os.environ.get("DDA_USER_TOKEN").strip()),
                     ("file-home", lambda:open(os.environ['HOME']+"/.secret-ddosa-client").read().strip()),
                     ("file-env-fn", lambda:open(os.environ['DDOSA_SECRET']).read().strip()),
                     ]:
@@ -203,7 +204,7 @@ class RemoteDDOSA(object):
             raise Exception("adapter %s not allowed!"%adapter)
         self._service_url=service_url
 
-    def prepare_request(self,target,modules=[],assume=[],inject=[],prompt_delegate=False,callback=None):
+    def prepare_request(self,target,modules=[],assume=[],inject=[],prompt_delegate=True,callback=None):
         log("modules", ",".join(modules))
         log("assume", ",".join(assume))
         log("service url:",self.service_url)
@@ -233,7 +234,7 @@ class RemoteDDOSA(object):
     def poke(self):
         return self.query("poke")
 
-    def query(self,target,modules=[],assume=[],inject=[],prompt_delegate=False,callback=None):
+    def query(self,target,modules=[],assume=[],inject=[],prompt_delegate=True,callback=None):
         try:
             p=self.prepare_request(target,modules,assume,inject,prompt_delegate,callback)
             url=p['url']
@@ -270,8 +271,8 @@ class RemoteDDOSA(object):
 
             raise WorkerException("no json was produced!",content=response.content,worker_output=worker_output,product_exception=e)
         except Exception as e:
-            log("exception decoding json:", e)
-            log("raw content: ", response.content, logtype="error")
+            logger.error("exception decoding json: %s", repr(e))
+            logger.error("raw content: %s", response.content)
             open("tmp_response_content.txt", "wt").write(response.text)
             raise Exception(f"can not decode json: {response.text}")
 
@@ -295,34 +296,9 @@ class AutoRemoteDDOSA(RemoteDDOSA):
         ddcache_root_local = os.environ['INTEGRAL_DDCACHE_ROOT']
         return url, ddcache_root_local
 
-    def from_config(self,config_version):
-        if config_version is None:
-            if 'DDOSA_WORKER_VERSION' in os.environ:
-                config_version = os.environ['DDOSA_WORKER_VERSION']
-            else:
-                config_version = "devel"
-
-        log("from config:", config_version)
-
-        if config_version == "":
-            config_suffix = ''
-        else:
-            config_suffix = '_' + config_version
-
-        config_fn = '/etc/ddosa-docker/config%s.py' % config_suffix
-        log(":", config_fn)
-
-        ddosa_config = imp.load_source('ddosa_config', config_fn)
-
-        ddcache_root_local = ddosa_config.ddcache_root_local
-        url = ddosa_config.url
-
-        return url, ddcache_root_local
-
     def discovery_methods(self):
         return [
                     'from_env',
-                    'from_config',
             ]
 
 
@@ -365,7 +341,7 @@ def main():
     parser.add_argument('-m',dest='modules',action='append',default=[])
     parser.add_argument('-a',dest='assume',action='append',default=[])
     parser.add_argument('-i',dest='inject',action='append',default=[])
-    parser.add_argument('-D',dest='prompt_delegate',action='store_true',default=False)
+    parser.add_argument('-D',dest='prompt_delegate',action='store_true',default=True)
     parser.add_argument('-v',dest='verbose',action='store_true',default=False)
 
     args = parser.parse_args()
